Change in osmo-bts[master]: osmo-bts-trx: measure interference levels on TRXC_IDLE

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

fixeria gerrit-no-reply at lists.osmocom.org
Thu Jun 17 22:34:13 UTC 2021


fixeria has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-bts/+/24715 )


Change subject: osmo-bts-trx: measure interference levels on TRXC_IDLE
......................................................................

osmo-bts-trx: measure interference levels on TRXC_IDLE

Change-Id: Ic3030dba5eb223177298aa4e43559a93dc3d1392
Related: SYS#5313, OS#1569
---
M src/common/scheduler.c
M src/osmo-bts-trx/trx_vty.c
2 files changed, 5 insertions(+), 2 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bts refs/changes/15/24715/1

diff --git a/src/osmo-bts-trx/trx_vty.c b/src/osmo-bts-trx/trx_vty.c
index fabe9c0..62fab33 100644
--- a/src/osmo-bts-trx/trx_vty.c
+++ b/src/osmo-bts-trx/trx_vty.c
@@ -100,6 +100,9 @@
 				tn, mf->name, VTY_NEWLINE);
 			vty_out(vty, "    pending DL prims    : %u%s",
 				llist_count(&l1ts->dl_prims), VTY_NEWLINE);
+			vty_out(vty, "    interference        : %ddBm%s",
+				l1ts->chan_state[TRXC_IDLE].meas.interf_avg,
+				VTY_NEWLINE);
 		}
 	}
 

diff --git a/src/common/scheduler.c b/src/common/scheduler.c
index 9796506..3dd7693 100644
--- a/src/common/scheduler.c
+++ b/src/common/scheduler.c
@@ -1491,8 +1491,8 @@
 
 	/* check if channel is active */
 	if (!TRX_CHAN_IS_ACTIVE(l1cs, bi->chan)) {
-		/* handle noise measurements */
-		if (TRX_CHAN_IS_DEDIC(bi->chan))
+		/* handle noise measurements on dedicated and idle channels */
+		if (TRX_CHAN_IS_DEDIC(bi->chan) || bi->chan == TRXC_IDLE)
 			trx_sched_noise_meas(l1cs, bi);
 		return 0;
 	}
-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bts/+/24715
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bts
Gerrit-Branch: master
Gerrit-Change-Id: Ic3030dba5eb223177298aa4e43559a93dc3d1392
Gerrit-Change-Number: 24715
Gerrit-PatchSet: 1
Gerrit-Owner: fixeria <vyanitskiy at sysmocom.de>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20210617/a5fde0a9/attachment.htm>


More information about the gerrit-log mailing list